==> jc-1.4.0.tar.gz: jas/GenericAttr.h <==
// public class jas.GenericAttr

// class file dependencies
// @dep_class d696009c5c0953cf jas_GenericAttr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_GenericAttr_H_
#define _JC_jas_GenericAttr_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_GenericAttr$sub_refs	_jc_jas_GenericAttr$sub_refs;
typedef struct _jc_jas_GenericAttr$sub_nonrefs	_jc_jas_GenericAttr$sub_nonrefs;
typedef struct _jc_jas_GenericAttr$refs	_jc_jas_GenericAttr$refs;
typedef struct _jc_jas_GenericAttr$nonrefs	_jc_jas_GenericAttr$nonrefs;
typedef struct _jc_jas_GenericAttr$object	_jc_jas_GenericAttr$object;

typedef const struct _jc_jas_GenericAttr$vmethods	_jc_jas_GenericAttr$vmethods;
typedef const struct _jc_jas_GenericAttr$vtable	_jc_jas_GenericAttr$vtable;
typedef const struct _jc_jas_GenericAttr$vtype	_jc_jas_GenericAttr$vtype;

// Constructors
extern void _jc_jas_GenericAttr$method$_init$2325051ac90ba1ae(_jc_env *, struct _jc_jas_GenericAttr$object *, struct _jc_jas_CP$object *, struct _jc_byte_array *);
extern void _jc_jas_GenericAttr$method$_init$8978305ea064370f(_jc_env *, struct _jc_jas_GenericAttr$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *);

// Virtual methods
extern void _jc_jas_GenericAttr$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_GenericAttr$object *, struct _jc_jas_ClassEnv$object *);
extern jint _jc_jas_GenericAttr$method$size$345df5220fc60ade(_jc_env *, struct _jc_jas_GenericAttr$object *);
extern void _jc_jas_GenericAttr$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_GenericAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_GenericAttr$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_GenericAttr$method_info$size$345df5220fc60ade;
extern _jc_method _jc_jas_GenericAttr$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_GenericAttr$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_GenericAttr$object *, struct _jc_jas_ClassEnv$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_jas_GenericAttr$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_GenericAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_GenericAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_GenericAttr$vmethods	jas_GenericAttr;
};

// Vtype
struct _jc_jas_GenericAttr$vtype {
	_jc_type			type;
	_jc_jas_GenericAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_GenericAttr$sub_refs {
	struct _jc_jas_CP$object	*attr__5fname;
	_jc_byte_array	*data;
};

// Reference instance fields (object)
struct _jc_jas_GenericAttr$refs {
    _jc_jas_GenericAttr$sub_refs	jas_GenericAttr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_GenericAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_GenericAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_GenericAttr$sub_nonrefs	jas_GenericAttr;
};

// Object instance structure
struct _jc_jas_GenericAttr$object {
	_jc_jas_GenericAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_GenericAttr$vtype	*vtype;
	_jc_jas_GenericAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_GenericAttr$vtype _jc_jas_GenericAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_GenericAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_GenericAttr$class_object;

#endif	/* _JC_jas_GenericAttr_H_ */

==> jc-1.4.6.tar.gz: jas/GenericAttr.h <==
// public class jas.GenericAttr

// class file dependencies
// @dep_class d696009c5c0953cf jas_GenericAttr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_GenericAttr_H_
#define _JC_jas_GenericAttr_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_GenericAttr$sub_refs	_jc_jas_GenericAttr$sub_refs;
typedef struct _jc_jas_GenericAttr$sub_nonrefs	_jc_jas_GenericAttr$sub_nonrefs;
typedef struct _jc_jas_GenericAttr$refs	_jc_jas_GenericAttr$refs;
typedef struct _jc_jas_GenericAttr$nonrefs	_jc_jas_GenericAttr$nonrefs;
typedef struct _jc_jas_GenericAttr$object	_jc_jas_GenericAttr$object;

typedef const struct _jc_jas_GenericAttr$vmethods	_jc_jas_GenericAttr$vmethods;
typedef const struct _jc_jas_GenericAttr$vtable	_jc_jas_GenericAttr$vtable;
typedef const struct _jc_jas_GenericAttr$vtype	_jc_jas_GenericAttr$vtype;

// Constructors
extern void _jc_jas_GenericAttr$method$_init$2325051ac90ba1ae(_jc_env *, struct _jc_jas_GenericAttr$object *, struct _jc_jas_CP$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_jas_GenericAttr$method$_init$8978305ea064370f(_jc_env *, struct _jc_jas_GenericAttr$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_GenericAttr$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_GenericAttr$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern jint _jc_jas_GenericAttr$method$size$345df5220fc60ade(_jc_env *, struct _jc_jas_GenericAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_GenericAttr$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_GenericAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_GenericAttr$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_GenericAttr$method_info$size$345df5220fc60ade;
extern _jc_method _jc_jas_GenericAttr$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_GenericAttr$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_GenericAttr$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_jas_GenericAttr$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_GenericAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_GenericAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_GenericAttr$vmethods	jas_GenericAttr;
};

// Vtype
struct _jc_jas_GenericAttr$vtype {
	_jc_type			type;
	_jc_jas_GenericAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_GenericAttr$sub_refs {
	struct _jc_jas_CP$object	*attr__5fname;
	_jc_byte_array	*data;
};

// Reference instance fields (object)
struct _jc_jas_GenericAttr$refs {
    _jc_jas_GenericAttr$sub_refs	jas_GenericAttr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_GenericAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_GenericAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_GenericAttr$sub_nonrefs	jas_GenericAttr;
};

// Object instance structure
struct _jc_jas_GenericAttr$object {
	_jc_jas_GenericAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_GenericAttr$vtype	*vtype;
	_jc_jas_GenericAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_GenericAttr$vtype _jc_jas_GenericAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_GenericAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_GenericAttr$class_object;

#endif	/* _JC_jas_GenericAttr_H_ */
